<?xml version="1.0" encoding="iso-8859-1"?>

<!-- CONTACT: XML data to a HTML view formatting
 
 Bertrand Le Quellec (c) 2014-2016
 
 Version: 1.2 English Release - Created: 2014-09-28
  
 Changed: 2014-10-21 - suppression feuille de style de base par des valeurs globales
 Changed: 2014-11-30 - ajout style sur la dimension du logo affich
 Changed: 2016-03-20 - prise en charge des labels des statuts sur Historique-Evnement
 
 Description:
 A generic Xml file from one Xml object data formatting Xsl file,
 representative structure a Client/Contact.
 -->

<xsl:stylesheet id="stylesheet" version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  
  <!-- The variables indicating the Page Settings. -->
  <xsl:variable name="margin"              select="'2px'" />
  <xsl:variable name="padding"             select="'5px'" />
  <xsl:variable name="background_color"    select="'#F4FAFC'" />
  <xsl:variable name="font_size"           select="'75%'" />
  <xsl:variable name="font_family"         select="'Verdana, Geneva, Tahoma, sans-serif'" />

  <!-- The variables designating colours. -->
  <xsl:variable name="legendtop_color"     select="'Lavender'" />
  <xsl:variable name="legendleft_color"    select="'#B8CCEE'" />
  <xsl:variable name="rowseparator_color"  select="'Black'" />
  <xsl:variable name="content_color"       select="'#B8CCDC'" />
  <xsl:variable name="comment_color"       select="'#ffebcd'" />
  <xsl:variable name="actionleft_color"    select="'lightgrey'" />

  <!-- The variables for the formatting of the main tables. -->
  <xsl:variable name="table_color"         select="'#ffffff'" />
  <xsl:variable name="table_border"        select="'0'" />
  <xsl:variable name="table_spacing"       select="'1'" />
  <xsl:variable name="table_padding"       select="'0'" />
  <xsl:variable name="table_font"          select="'normal serif'" />

  <!-- The variables for the formatting of secondary tables. -->
  <xsl:variable name="table2_color"         select="'#ffffff'" />
  <xsl:variable name="table2_border"        select="'0'" />
  <xsl:variable name="table2_spacing"       select="'1'" />
  <xsl:variable name="table2_padding"       select="'0'" />

  <!-- The formatting of the html output method. -->
  <xsl:output
   method="html"
   encoding="ISO-8859-1"
   doctype-public="-//W3C//DTD HTML 4.01//EN"
   doctype-system="http://www.w3.org/TR/html4/strict.dtd"
   indent="yes" />

  <!-- Body of the HTML result: starting point -->
  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">

      <head>
        <title>
          <xsl:value-of disable-output-escaping="yes" select="Contact/Contact/Firstname" /> <xsl:value-of disable-output-escaping="yes" select="Contact/Contact/Lastname" />
        </title>
        <meta name="description" content="contact card information" />
        <meta name="publisher" content="BLQ software" />
        <meta name="author" content="BLQ software" />
        <meta name="copyright" content="BLQ software" />
        <meta name="http.language" content="English" />
        <meta name="Language" content="EN" />
        <meta http-equiv="Content-Language" content="en" />

        <!--
        Designation of a style sheet
        <link href="style.css" rel="stylesheet" media="all" type="text/css" />

        Appointment of a dedicated print style sheet 
       <link rel="stylesheet" type="text/css" media="print" href="print.css" />
       -->
      </head>

      <body style="margin:{$margin}; padding:{$padding}; background-color:{$background_color}; font-size:{$font_size}; font-family:{$font_family}; ">
        <!-- *********************************************
            Processing of the Xml root named Contact 
           ********************************************* -->
        <xsl:apply-templates select="Contact" />
      </body>
    </html>
  </xsl:template>

  <!-- 
   ===========================================
    CONTACT: first-level Xml processing 
   =========================================== -->
  <xsl:template match="Contact">

    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <th width="40%" align="left">
          <font size="+1">
            <b>
              <xsl:choose>
                <xsl:when test="Contact/Rank= '4'">
                  <xsl:text>* * * *</xsl:text>
                </xsl:when>
                <xsl:when test="Contact/Rank= '3'">
                  <xsl:text>* * *</xsl:text>
                </xsl:when>
                <xsl:when test="Contact/Rank= '2'">
                  <xsl:text>* *</xsl:text>
                </xsl:when>
                <xsl:when test="Contact/Rank= '1'">
                  <xsl:text>*</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <!-- Inserting a space -->
                  <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </b>
          </font>
        </th>

        <!-- CREATION DATE-->
        <th align="right">
          <font size="-2">
            <i>
              created
              <xsl:value-of select="@created" />
            </i>
          </font>
        </th>

        <!-- DATE MODIFIED -->
        <th align="right">
          <font size="-2">
            <i>
              changed
              <xsl:value-of select="@changed" />
            </i>
          </font>
        </th>
      </tr>
    </table>

    <!-- ======================================================================= -->
    <!-- Array of values -->
    <p>
    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <!-- CONTACT LASTNAME -->
        <th bgcolor="{$comment_color}">
          <font style="text-transform: uppercase; font-size:large;">
            <xsl:value-of select="Contact/Lastname" />
          </font>
        </th>

        <!-- CONTACT FIRSTNAME -->
        <th bgcolor="{$comment_color}" width="30%">
          <font style="text-transform: uppercase; font-size:large;">
            <xsl:value-of select="Contact/Firstname" />
          </font>
        </th>
      </tr>

      <!-- == ... ======================================================================= -->
      <!-- NOTE -->
      <tr>
        <!-- NOTE: loop through the rows of Note -->
        <th valign="top" align="left">
          <code>
            <xsl:for-each select="Contact/Notes">
              <xsl:apply-templates select="Item" />
            </xsl:for-each>
          </code>
        </th>

        <!-- LOGO & WEB SITE-->
        <th valign="top" width="30%">
          <!-- LOGO -->
          <xsl:if test = "normalize-space(Contact/Logo)">
            <img src="{Contact/Logo}" style="width:150px; height:150px;" />
            <!-- Adding newline if Web link after the logo -->
            <xsl:if test = "normalize-space(Contact/Web)">
              <br />
            </xsl:if>
          </xsl:if>

          <!-- WEB SITE -->
          <xsl:if test = "normalize-space(Contact/Web)">
            <a href="{Contact/Web}" target="_blank">
              <xsl:value-of select="Contact/Web" />
            </a>
          </xsl:if>
        </th>
      </tr>

      <!-- Closure of the Html table -->
    </table>
    </p>
    
    <!-- == ADDRESS ======================================================================= -->
    <xsl:choose>
      <!-- The array of addresses will contain data -->
      <xsl:when test="count(Contact/Addresses/Address) > 0">
        <xsl:if test="Contact/Addresses/Address[@key] != ''">
        <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
          <tr>
            <th width="100%" valign="top">
              <br />
              <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
                <tr>
                  <th colspan="4" align="center" bgcolor="{$legendleft_color}">
                    <font style="text-transform: capitalize; font-size:large; font-weight: bold;">addresses</font>
                  </th>
                </tr >

                <!-- == SEPARATOR =============================================================== -->
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="4"></th>
                </tr>

                <!-- == ... ======================================================================= -->
                <!-- Loop through the list addresses of the Xml file -->
                <xsl:for-each select="Contact/Addresses">
                  <xsl:apply-templates select="Address" />
                </xsl:for-each>
                <!-- Closure of the addresses Html table -->
              </table >
            </th>
            <!-- == ... ======================================================================= -->
          </tr>
        </table>
        </xsl:if>
      </xsl:when>
    </xsl:choose>

    <p>
    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <!-- 2 ===> Scoreboard of the Emails <=== -->
        <th valign="top">
          <!-- Test the number of Nodes, as only non-empty information are to be treated -->
          <xsl:choose>
            <xsl:when test="count(Contact/Emails/Email) > 0">
              <!-- The array of emails will contain data -->
              <table border="{$table_border}" width="100%">
                <tr>
                  <th colspan="2" align="center" bgcolor="{$legendleft_color}">
                    <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                        <xsl:text disable-output-escaping="yes">emails</xsl:text>
                    </font>
                  </th>
                </tr >

                <!-- Loop through the list of emails from the Xml file -->
                <xsl:for-each select="Contact/Emails">
                  <xsl:apply-templates select="Email" />
                </xsl:for-each>
                <!-- Closure of the Html of the phones table -->
              </table >
            </xsl:when>

            <xsl:when test="count(Contact/Emails/Email)= 0">
              <!-- Insertion of a space instead of the table empty emails -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:when>
          </xsl:choose>
        </th>
        <!-- == END EMAILS ==================================================================== -->

        <!-- 3 ===> Phones scoreboard <=== -->
        <!-- Test the number of Nodes, as only non-empty information are to be treated -->
        <th valign="top">          
          <xsl:choose>
            <xsl:when test="count(Contact/Phones/Phone) > 0">
              <!-- The array of phones will contain data -->
              <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
                <tr>
                  <th colspan="2" align="center" bgcolor="{$legendleft_color}">
                    <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                        <xsl:text disable-output-escaping="yes">phones</xsl:text>
                    </font>
                  </th>
                </tr >

                <!-- Loop on the list of phones of the Xml file -->
                <xsl:for-each select="Contact/Phones">
                  <xsl:apply-templates select="Phone" />
                </xsl:for-each>
                <!-- Closure of the Html of the phones table -->
              </table >
            </xsl:when>

            <xsl:when test="count(Contact/Phones/Phone)= 0">
              <!-- Inserting a space instead of the empty array phones -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:when>
          </xsl:choose>
        </th>
        <!-- == END PHONES ==================================================================== -->
      </tr>
    </table>
    </p>
    
    <!-- 4 ===> Array of custom fields <=== -->
    <!-- Test the number of Nodes, as only non-empty information are to be treated -->
    <xsl:if test="count(Contact/Customs/Custom) > 0">
      <p>
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr>
          <th colspan="2" align="left" bgcolor="{$legendleft_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">additional information</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Loop through the list of the Customs of the Xml file -->
        <xsl:for-each select="Contact/Customs">
          <xsl:apply-templates select="Custom" />
        </xsl:for-each>
        <!-- Closure of the Customs Html table -->
      </table >
      </p>
    </xsl:if>

    <!-- 5 ===> Array of Colleagues and Relations <=== -->
    <!-- Test the number of Nodes, as only non-empty information are to be treated -->
    <xsl:if test="count(Professional/Colleagues/Colleague) > 0">
      <p>
        <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
          <tr>
            <th colspan="5" align="left" bgcolor="{$legendtop_color}">
              <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">colleagues - relations</xsl:text>
              </font>
            </th>
          </tr>

          <tr>
            <th style="text-align: center">
              <table bgcolor="{$table_color}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="80%">
                <xsl:for-each select="Professional/Colleagues">
                  <xsl:apply-templates select="Colleague"  />
                </xsl:for-each>
              </table >
            </th>
          </tr>
        </table>
      </p>
    </xsl:if>
    
    <!-- 6 ===> External links noticeboard <=== -->
    <!-- Test the number of Nodes, as only non-empty information are to be treated -->
    <xsl:if test="count(Contact/ExternalLinks/Link) > 0">
      <p>
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr>
          <th colspan="2" align="left" bgcolor="{$legendtop_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">external links</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Loop through the list of external links in the Xml file -->
        <xsl:for-each select="Contact/ExternalLinks">
          <xsl:apply-templates select="Link" />
        </xsl:for-each>
        <!-- Closure of the Html of the external links table -->
      </table >
      </p>
    </xsl:if>

    <!-- 7 ===> Historical scoreboard <=== -->
    <!-- Test the number of Nodes, as only non-empty information are to be treated -->
    <xsl:if test="count(Historical/History) > 0">
      <p>
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr>
          <th colspan="3" align="left" bgcolor="{$legendtop_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">historical</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Loop through the list of historical items in the Xml file -->
        <xsl:for-each select="Historical">
          <xsl:apply-templates select="History" />
        </xsl:for-each>
        <!-- Closure of the Html of the historical table -->
      </table >
      </p>
    </xsl:if>
  </xsl:template>

  <!--
   ==============================================================
    The called function to process the lines of a Note
   ============================================================== -->
  <xsl:template match="Item">
    <xsl:value-of select="." />
    <br />
  </xsl:template>

  <!--
   ==============================================================
    The called function to process the tree of addresses
   ============================================================== -->
  <xsl:template match="Address">
    <tr>
      <th bgcolor="{$content_color}" align="center">
        <!-- TYPE -->
        <xsl:value-of select="@key" />
      </th>
      <th>
        <!-- STREET -->
        <xsl:value-of select="Street" />
      </th>
      <th width="20%">
        <!-- ZIP/POSTAL CODE -->
        <xsl:value-of select="Zipcode" />
      </th>
      <th width="20%">
        <!-- CITY -->
        <xsl:value-of select="City" />
      </th>
    </tr>

    <!-- Second row -->
    <tr>
      <th>
        <!-- empty -->
      </th>
      <th>
        <!-- empty -->
      </th>
      <th width="20%">
        <!-- STATE -->
        <xsl:value-of select="State" />
      </th>
      <th width="20%">
        <!-- COUNTRY -->
        <xsl:value-of select="Country" />
      </th>
    </tr>
    <tr>
      <th bgcolor="{$rowseparator_color}" colspan="4"></th>
    </tr>
  </xsl:template>

  <!--
   ================================================================
    The called function to process the tree of Emails
    Integration of the call via a URL link
   ================================================================ -->
  <xsl:template match="Email">
    <tr>
      <th bgcolor="{$content_color}" align="right">
        <!-- EMAIL TYPE -->
        <xsl:value-of select="Type"/>
        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
      </th>

      <th align="left">
        <!-- DATA + URL -->
        <a href="mailto:{Data}">
          <xsl:value-of select="Data" />
        </a>
      </th>
    </tr>
  </xsl:template>

  <!--
   ================================================================
    The called function to process the tree of Phones
    Integration of the call via a URL link
   ================================================================ -->
  <xsl:template match="Phone">
    <tr>
      <th bgcolor="{$content_color}" align="right">
        <!-- PHONE TYPE -->
        <xsl:value-of select="Type"/>
        <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
      </th>

      <th align="left">
        <!-- DATA + URL -->
        <a href="tel:{Data}">
          <xsl:value-of select="Data" />
        </a>
      </th>
    </tr>
  </xsl:template>

  <!--
   ==========================================================================
    The called function to process the tree of the custom fields
   ========================================================================== -->
  <xsl:template match="Custom">
    <xsl:if test = "normalize-space(Data)">
      <tr>
        <th bgcolor="{$content_color}" align="right">
          <!-- LABEL -->
          <xsl:value-of select="Label"/>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </th>

        <th align="left">
          <!-- DATA -->
          <xsl:value-of select="Data" />
        </th>
      </tr>
    </xsl:if>
  </xsl:template>

  <!--
   ==========================================================================
    The called function to process the tree of Colleague/Relation 
   ========================================================================== -->
  <xsl:template match="Colleague">
    <!--
        STRANGE CODE:
        I GUESS THERE IS A BETTER CODE TO EXTRACT VALUES FROM ONE STRING,
        BUT I DON'T KNOW HOW TO DO...
        -->
    <!-- NAME -->
    <xsl:variable name="item1" select="substring-before(., ']|[')" />
    <xsl:variable name="itemTmp1" select="substring-after(., ']|[')" />
    <!-- TELEPHONE -->
    <xsl:variable name="item2" select="substring-before($itemTmp1, ']|[')" />
    <xsl:variable name="itemTmp2" select="substring-after($itemTmp1, ']|[')" />
    <!-- FUNCTION -->
    <xsl:variable name="item3" select="substring-before($itemTmp2, ']|[')" />
    <xsl:variable name="itemTmp3" select="substring-after($itemTmp2, ']|[')" />
    <!-- EMAIL -->
    <xsl:variable name="item4" select="substring-before($itemTmp3, ']|[')" />

    <tr>
      <!-- Alternance des couleurs de fond de chaque ligne  -->
      <xsl:if test="position() mod 2 = 0">
        <xsl:attribute name="bgcolor">lightgrey</xsl:attribute>
        <!-- 
        En cas de passage d'une couleur incluse dans une variable globale : $actionleft_color
        la couleur visualise est diffrente ! Donc la couleur est directement crite
        A explorer plus tard... -->
      </xsl:if>
      <th align="left">
        <font style="font-weight: normal;">
          <!-- NAME -->
          <xsl:value-of select="string($item1)" />
        </font >
      </th>
      <th align="left">
        <a href="tel:{$item2}">
          <!-- PHONE -->
          <xsl:value-of select="string($item2)" />
        </a>
      </th>
      <th align="left">
        <!-- FUNCTION -->
        <xsl:value-of select="string($item3)" />
      </th>
      <th align="left">
        <a href="mailto:{$item4}">
          <!-- EMAIL -->
          <xsl:value-of select="string($item4)" />
        </a>
      </th>
    </tr>
  </xsl:template>
  
  <!--
   =====================================================================
    The called function to process the tree of external links 
   ===================================================================== -->
  <xsl:template match="Link">
    <xsl:if test = "normalize-space(Data)">
      <tr>
        <th bgcolor="{$content_color}" align="middle">
          <!-- Category -->
          <xsl:value-of select="LinkCategory" />
        </th>

        <th align="left">
          <!-- DATA: effective link on the data -->
          <xsl:choose>
            <!-- File with local access -->
            <xsl:when test="@type= 'File'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data}">
                  <xsl:value-of select="concat(substring-before(Data, '|') ,':', substring-after(Data, '|'))" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Directory with local access -->
            <xsl:when test="@type= 'Folder'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data}">
                  <xsl:value-of select="concat(substring-before(Data, '|') ,':', substring-after(Data, '|'))" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Executable application -->
            <xsl:when test="@type= 'Exe'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data} {Parameters}" target="_blank">
                  <xsl:value-of select="Data" />
                  <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                  <xsl:value-of select="Parameters" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- URL: Web, FTP, etc. -->
            <xsl:when test="@type= 'Url'">
              <xsl:if test="normalize-space(Data)">
                <a href="{Data}{Parameters}" target="_blank">
                  <xsl:value-of disable-output-escaping="yes" select="Data" />
                  <xsl:value-of disable-output-escaping="yes" select="Parameters" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Email -->
            <xsl:when test="@type= 'Mail'">
              <xsl:if test="normalize-space(Data)">
                <a href="mailto:{Data}">
                  <xsl:value-of select="Data" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Image on a local -->
            <xsl:when test="@type= 'Image'">
              <xsl:if test="normalize-space(Data)">
                <img src="{Data}" width="100" height="100"/>
              </xsl:if>
            </xsl:when>

            <!-- Image on a Web File -->
            <xsl:when test="@type= 'ImageWeb'">
              <xsl:if test="normalize-space(Data)">
                <img src="{Data}" />
              </xsl:if>
            </xsl:when>

            <!-- No specific treatment of the link -->
            <xsl:otherwise>
              <xsl:if test="normalize-space(Data)">
                <xsl:value-of select="Data" />
              </xsl:if>
            </xsl:otherwise>
          </xsl:choose>
        </th>
      </tr >

      <!-- NOTES: an optional description on the link -->
      <xsl:if test = "normalize-space(LinkNotes)">
        <tr>
          <th colspan="2" align="left">
            <code>
              <xsl:value-of select="LinkNotes" />
            </code>
          </th>
        </tr>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <!--
   ==========================================================================
    The called function to process the tree of the historical
   ========================================================================== -->
  <xsl:template match="History">
    <tr>
      <th bgcolor="{$content_color}" align="middle">
        <!-- DATE -->
        <font size="-1">
          <xsl:value-of select="@date"/>
        </font>
      </th>

      <th align="left">
        <!-- LABEL -->
        <code>
          <xsl:value-of select="Data"/>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </code>
      </th>

      <th bgcolor="{$comment_color}" align="middle">
        <!-- STATUS -->
        <font style="text-transform: capitalize; font-size:small;">
          <xsl:choose>
            <!-- Old treatment of the data -->
            <xsl:when test="Status= 'unDefined'">undefined</xsl:when>
            <xsl:when test="Status= 'Diferred'">diferred</xsl:when>
            <xsl:when test="Status= 'Failed'">failed</xsl:when>
            <xsl:when test="Status= 'Pending'">pending</xsl:when>
            <xsl:when test="Status= 'inProgress'">in progress</xsl:when>
            <xsl:when test="Status= 'notStarted'">not started</xsl:when>
            <xsl:when test="Status= 'Completed'">completed</xsl:when>
            <xsl:when test="Status= 'neverCompleted'">never completed</xsl:when>
            <!-- New treatment of the data -->
            <xsl:otherwise>
              <xsl:apply-templates select="Status" />
            </xsl:otherwise>
          </xsl:choose>
        </font>
      </th>
    </tr>
  </xsl:template>

  <xsl:template match="Status">
    <xsl:if test="@Label">
      <xsl:value-of select="@Label"/>
    </xsl:if>
  </xsl:template>
  
</xsl:stylesheet>



